"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function format(locale, value, separator) {
    if (!separator)
        separator = "/";
    // const literal = String(value).indexOf("-") > 0 ? "-" : "/";
    // if (locale.toLocaleLowerCase() === "fa")
    //   value = convert("en", value).YYYY_MM_dd;
    var date = new Date(String(value));
    var monthName = new Intl.DateTimeFormat(locale, {
        month: "long",
    }).format(date);
    var fmt = new Intl.DateTimeFormat(locale, {
        weekday: "long",
        day: "numeric",
        month: "numeric",
        year: "numeric",
        hour: "numeric",
        minute: "numeric",
        second: "numeric",
        hour12: false,
    })
        .formatToParts(date)
        .reduce(function (acc, part) {
        acc[part.type] = toEnglishNumber(String(part.value));
        return acc;
    }, {});
    fmt.month = fmt.month.toString().padStart(2, "0");
    fmt.day = fmt.day.toString().padStart(2, "0");
    return {
        YYYY_MM_dd_HH_MM_ss: "".concat(fmt.year + separator + fmt.month + separator + fmt.day, " ").concat(fmt.hour, ":").concat(fmt.minute, ":").concat(fmt.second),
        YYYY_MM_dd_HH_MM: "".concat(fmt.year + separator + fmt.month + separator + fmt.day, " ").concat(fmt.hour, ":").concat(fmt.minute),
        HH_MM_ss: "".concat(fmt.hour, ":").concat(fmt.minute, ":").concat(fmt.second),
        HH_MM: "".concat(fmt.hour, ":").concat(fmt.minute),
        YYYY_MM_dd: "".concat(fmt.year + separator + fmt.month + separator + fmt.day),
        YYYY_M_dd: " ".concat(fmt.day, " ").concat(monthName, " ").concat(fmt.year),
        YYYY_M: "".concat(fmt.year, " ").concat(monthName),
        W_YYYY_M_dd: "".concat(fmt.weekday, " ").concat(fmt.day, " ").concat(monthName, " ").concat(fmt.year),
        W_YYYY_M_dd_HH_MM: "".concat(fmt.weekday, " ").concat(fmt.day, " ").concat(monthName, " ").concat(fmt.year, " ").concat(fmt.hour, " ").concat(fmt.minute),
        W_dd_M: "".concat(fmt.weekday, " ").concat(fmt.day, " ").concat(monthName),
        W_dd_MM: "".concat(fmt.weekday, " - ").concat(fmt.month + separator + fmt.day),
        dd_M: "".concat(fmt.day, " ").concat(monthName),
        YYYY: "".concat(fmt.year),
        MM: Number(fmt.month),
        M: monthName,
        d: Number(fmt.day),
        W: "".concat(fmt.weekday),
        WW: getWeekdayNumber(fmt.weekday, locale).toString(),
        Unix: Math.floor(new Date(date).getTime() / 1000),
    };
}
function convert(locale, value, separator) {
    if (locale.toLocaleLowerCase() === "fa") {
        return format("fa", value, separator);
    }
    else {
        // Assuming toGregorian is implemented elsewhere
        return toGregorian(value, separator);
    }
}
function addDays(locale, value, days, separator) {
    var _a;
    if (locale.toLocaleLowerCase() === "fa") {
        var date = new Date((_a = convert("en", value)) === null || _a === void 0 ? void 0 : _a.YYYY_MM_dd);
        date.setDate(date.getDate() + days);
        return format("fa", date, separator);
    }
    else {
        var date = new Date(String(value));
        date.setDate(date.getDate() + days);
        return format("en", date, separator);
    }
}
function DaysInMonth(locale, year, month) {
    var _a, _b;
    if (locale.toLocaleLowerCase() === "fa") {
        var date1 = new Date((_a = convert("en", "".concat(year, "/").concat(month, "/1"))) === null || _a === void 0 ? void 0 : _a.YYYY_MM_dd);
        if (month === 12) {
            year++;
            month = 1;
        }
        else {
            month++;
        }
        var date2 = new Date((_b = convert("en", "".concat(year, "/").concat(month, "/1"))) === null || _b === void 0 ? void 0 : _b.YYYY_MM_dd);
        return Math.round((date2 - date1) / (1000 * 60 * 60 * 24));
    }
    else {
        var d = new Date(year, month, 0);
        return d.getDate();
    }
}
function datoToNumber(date) {
    return Number(toEnglishNumber(String(date).replaceAll("/", "").replaceAll("-", "")));
}
function toEnglishNumber(value) {
    if (value == null)
        return "";
    var englishNumbers = "0123456789";
    var persianNumbers1 = "٠١٢٣۴۵۶٧٨٩";
    var persianNumbers2 = "۰۱۲۳۴۵۶۷۸۹";
    var arabicNumbers = "٠١٢٣٤٥٦٧٨٩";
    var res = "";
    // @ts-ignore
    for (var _i = 0, value_1 = value; _i < value_1.length; _i++) {
        var c = value_1[_i];
        var index1 = persianNumbers1.indexOf(c);
        var index2 = persianNumbers2.indexOf(c);
        var index3 = arabicNumbers.indexOf(c);
        var index = index1 >= 0 ? index1 : index2 >= 0 ? index2 : index3;
        res += index >= 0 ? englishNumbers[index] : c;
    }
    return res;
}
function toElapsedTime(value) {
    var now = new Date(); //.startOf('day');
    var date = new Date(String(value));
    // @ts-ignore
    var diffMS = now - date;
    var diffSecondes = Math.floor(diffMS / 1000);
    var diffMins = Math.floor(diffSecondes / 60);
    var diffHours = Math.floor(diffMins / 60);
    var diffDays = Math.floor(diffHours / 24);
    var diffWeeks = Math.floor(diffDays / 7);
    var diffMonths = Math.floor(diffDays / 30);
    var diffYears = Math.floor(diffMonths / 12);
    if (diffSecondes < 60) {
        return diffSecondes + " ثانیه پیش";
    }
    if (diffMins < 60) {
        return diffMins + " دقیقه پیش";
    }
    if (diffHours < 24) {
        return diffHours + " ساعت پیش";
    }
    if (diffDays < 30) {
        if (diffDays === 1) {
            return "دیروز";
        }
        if (diffDays % 7 === 0) {
            return diffWeeks + " هفته پیش";
        }
        return diffDays + " روز پیش";
    }
    if (diffMonths < 12) {
        return diffMonths + " ماه پیش";
    }
    if (diffYears > 0) {
        return diffYears + " سال پیش";
    }
    return "";
}
//#region private functions
// @ts-ignore
function toGregorian(value, separator) {
    var JalaliDate = {
        g_days_in_month: [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31],
        j_days_in_month: [31, 31, 31, 31, 31, 31, 30, 30, 30, 30, 30, 29],
    };
    var literal = String(value).indexOf("-") > 0 ? "-" : "/";
    if (!separator)
        separator = "/";
    var dateParts = (typeof value === "string" ? value : value.toISOString().split("T")[0]).split(literal);
    var j_y = parseInt(dateParts[0], 10);
    var j_m = parseInt(dateParts[1], 10);
    var j_d = parseInt(dateParts[2], 10);
    if (!isNaN(j_y) && !isNaN(j_m) && !isNaN(j_d)) {
        var jy = j_y - 979;
        var jm = j_m - 1;
        var jd = j_d - 1;
        var j_day_no = 365 * jy + Math.floor(jy / 33) * 8 + Math.floor(((jy % 33) + 3) / 4);
        for (var i_1 = 0; i_1 < jm; ++i_1)
            j_day_no += JalaliDate.j_days_in_month[i_1];
        j_day_no += jd;
        var g_day_no = j_day_no + 79;
        var gy = 1600 +
            400 *
                Math.floor(g_day_no / 146097); /* 146097 = 365*400 + 400/4 - 400/100 + 400/400 */
        g_day_no = g_day_no % 146097;
        var leap = true;
        if (g_day_no >= 36525) {
            /* 36525 = 365*100 + 100/4 */
            g_day_no--;
            gy +=
                100 *
                    Math.floor(g_day_no / 36524); /* 36524 = 365*100 + 100/4 - 100/100 */
            g_day_no = g_day_no % 36524;
            if (g_day_no >= 365)
                g_day_no++;
            else
                leap = false;
        }
        gy += 4 * Math.floor(g_day_no / 1461); /* 1461 = 365*4 + 4/4 */
        g_day_no %= 1461;
        if (g_day_no >= 366) {
            leap = false;
            g_day_no--;
            gy += Math.floor(g_day_no / 365);
            g_day_no = g_day_no % 365;
        }
        var i = 0;
        for (; g_day_no >= JalaliDate.g_days_in_month[i] + (i === 1 && leap ? 1 : 0); i++)
            g_day_no -= JalaliDate.g_days_in_month[i] + (i === 1 && leap ? 1 : 0);
        var gm = (i + 1).toString().padStart(2, "0");
        var gd = (g_day_no + 1).toString().padStart(2, "0");
        return format("en", new Date("".concat(gy + separator + gm + separator + gd)), separator);
    }
}
function getWeekdayNumber(weekdayString, locale) {
    if (locale === "en") {
        return [
            "Saturday",
            "Sunday",
            "Monday",
            "Tuesday",
            "Wednesday",
            "Thursday",
            "Friday",
        ].indexOf(weekdayString);
    }
    else {
        return [
            "شنبه",
            "یکشنبه",
            "دوشنبه",
            "سه‌شنبه",
            "چهارشنبه",
            "پنجشنبه",
            "جمعه",
        ].indexOf(weekdayString);
    }
}
//#endregion private functions
var sdate = {
    format: format,
    convert: convert,
    addDays: addDays,
    DaysInMonth: DaysInMonth,
    datoToNumber: datoToNumber,
    toEnglishNumber: toEnglishNumber,
    toElapsedTime: toElapsedTime,
};
exports.default = sdate;
//# sourceMappingURL=date.js.map